@@ -1,7 +1,23 @@
+#' Report whether the input is a "pvEBayes" object
+#'
+#' @param object a \code{pvEBayes} object, which is the output of the function
+#' \link{pvEBayes}.
+#'
+#' @returns logical
+#' @keywords internal
+#' @noRd
 is.pvEBayes <- function(object) {
   methods::is(object, "pvEBayes")
 }
 
+#' Report whether the input is a "pvEBayes_tuned" object
+#'
+#' @param object a \code{pvEBayes_tune} object, which is the output of the
+#' function \link{pvEBayes_tune}.
+#'
+#' @returns logical
+#' @keywords internal
+#' @noRd
 is.pvEBayes_tuned <- function(object) {
   methods::is(object, "pvEBayes_tuned")
 }
@@ -29,16 +45,22 @@ is.pvEBayes_tuned <- function(object) {
 #' rownames(valid_matrix) <- c("AE_1", "AE_2")
 #' colnames(valid_matrix) <- c("drug_1", "drug_2", "drug_3", "drug_4")
 #'
-#' tuned_object = pvEBayes_tune(valid_matrix,
-#'                             model = "general-gamma",
-#'                             return_all_fit = TRUE)
+#' tuned_object <- pvEBayes_tune(valid_matrix,
+#'   model = "general-gamma",
+#'   return_all_fit = TRUE
+#' )
 #' extract_all_fitted_models(tuned_object)
 #'
 extract_all_fitted_models <- function(object) {
   if (!is.pvEBayes_tuned(object)) {
-    stop("This function can only be used after tuning. Please apply to objects returned by 'pvEBayes_tune()'.")
+    stop(
+      paste0(
+        "This function can only be used after tuning.",
+        "Please apply to objects returned by 'pvEBayes_tune()'."
+      )
+    )
   }
-  return(object$tuning)
+  object$tuning
 }
 
 
@@ -73,10 +95,21 @@ extract_all_fitted_models <- function(object) {
 #'
 #' fit_with_draws <- posterior_draws(fit, n_posterior_draws = 1000)
 #'
+#' @srrstats {G2.0, G2.1, G2.2} length and value of single and vector inputs are properly
+#' checked.
+#' @srrstats {G2.0a, G2.1a} The length of single and vector inputs are explicitly
+#' described in the corresponding documentation.
+#' @srrstats {G2.4, G2.4a, G2.8} explicit conversion is used for integer input.
+#'
 posterior_draws <- function(obj,
-                                     n_posterior_draws = 1000) {
+                            n_posterior_draws = 1000) {
   stopifnot(is.pvEBayes(obj))
-
+  if (
+    !(is.numeric(n_posterior_draws) && length(n_posterior_draws) == 1 &&
+      n_posterior_draws %% 1 == 0 && n_posterior_draws > 0)) {
+    stop("'n_posterior_draws' must be a single positive integer.")
+  }
+  n_posterior_draws <- as.integer(n_posterior_draws)
   if (obj$model %in% c("KM", "efron")) {
     generate_posterior_fun <- .generate_posterior_grid_based
   } else {
@@ -93,6 +126,14 @@ posterior_draws <- function(obj,
 }
 
 
+#' Make rownames a extra column
+#'
+#' @param df a matrix with rownames
+#' @param var name of the extra column
+#'
+#' @returns a matrix with extra column
+#' @keywords internal
+#' @noRd
 .rownames_to_column <- function(df, var = "rowname") {
   # Create a new column from row names
   df[[var]] <- row.names(df)
@@ -103,31 +144,56 @@ posterior_draws <- function(obj,
   # Reorder columns to place the new column first
   df <- df[, c(var, setdiff(names(df), var))]
 
-  return(df)
+  df
 }
 
+#' Left join
+#'
+#' @param x a data frame
+#' @param y a data frame
+#' @param by specifications of the columns used for merging
+#'
+#' @returns a data frame
+#' @keywords internal
+#' @noRd
 .left_join_base <- function(x, y, by) {
   merge(x, y, by = by, all.x = TRUE)
 }
 
 
+#' Obtain posterior probability of being a signal
+#'
+#' @param obj a \code{pvEBayes} object, which is the output of the function
+#' \link{pvEBayes} or \link{pvEBayes_tune}.
+#'
+#' @returns a matrix
+#' @keywords internal
+#' @noRd
 .get_posterior_prob <- function(obj) {
   tmp <- obj$posterior_draws
-  # posterior::draws_of()
   (tmp > 1.001) %>%
     apply(c(2, 3), mean)
 }
 
+#' Report valid AE rows for ploting
+#'
+#' @param post_matrix a matrix
+#' @param N an IxJ contingency table showing pairwise counts of
+#' adverse events for I AEs (along the rows) and J drugs (along the columns).
+#' @param N_threshold integer greater than 0. Any AE-drug combination with
+#' observation smaller than N_threshold will be filtered out.
+#'
+#' @returns a logical vector
+#' @keywords internal
+#' @noRd
 .check_AEs <- function(post_matrix, N, N_threshold) {
   I <- nrow(N)
   J <- ncol(N)
   indi <- rep(FALSE, I)
   for (i in seq_len(I)) {
     tmp_indi <- (post_matrix[i, ] == max(post_matrix[i, ]))
-    if (sum(tmp_indi) > 0) {
-      if (sum(N[i, tmp_indi] > N_threshold) > 0) {
-        indi[i] <- TRUE
-      }
+    if (sum(N[i, tmp_indi] > N_threshold) > 0) {
+      indi[i] <- TRUE
     }
   }
   indi
@@ -147,15 +213,16 @@ posterior_draws <- function(obj,
 #'
 #' @param x a \code{pvEBayes} object, which is the output of the function
 #' \link{pvEBayes} or \link{pvEBayes_tune}.
-#' @param num_top_AEs number of most significant AEs appearing in the plot. Default to
-#' 10.
-#' @param num_top_drugs number of most significant drugs appearing in the plot. Default
-#' to 7.
-#' @param specified_AEs a vector of AE names that are specified to appear in the plot. If
-#' a vector of AEs is given, argument num_top_AEs will be ignored.
-#' @param specified_drugs a vector of drug names that are specified to appear in the plot.
-#' If a vector of drugs is given, argument num_top_drugs will be ignored.
-#' @param N_threshold integer greater than 0. Any AE-drug combination with
+#' @param num_top_AEs a number of most significant AEs appearing in the plot.
+#' Default to 10.
+#' @param num_top_drugs a number of most significant drugs appearing in the
+#' plot. Default to 7.
+#' @param specified_AEs a vector of AE names that are specified to appear in the
+#' plot. If a vector of AEs is given, argument num_top_AEs will be ignored.
+#' @param specified_drugs a vector of drug names that are specified to appear in
+#' the plot. If a vector of drugs is given, argument num_top_drugs will be
+#' ignored.
+#' @param N_threshold a integer greater than 0. Any AE-drug combination with
 #' observation smaller than N_threshold will be filtered out.
 #' @param text_shift numeric. Controls the relative position of text labels,
 #' (e.g., "N = 1", "E = 2"). A larger value shifts the "E = 2" further away from
@@ -184,6 +251,15 @@ posterior_draws <- function(obj,
 #'   x = fit
 #' )
 #'
+#' @srrstats {G2.0, G2.1, G2.2} length and value of single and vector inputs are properly
+#' checked.
+#' @srrstats {G2.0a, G2.1a} The length of single and vector inputs are explicitly
+#' described in the corresponding documentation.
+#' @srrstats {G2.4, G2.4a, G2.4b, G2.4c, G2.8} explicit conversion is used for
+#' integer, continuous and character inputs.
+#' @srrstats {G2.9, G2.10} inconsistent return when extracting a matrix is
+#' addressed.
+#'
 eyeplot_pvEBayes <- function(x,
                              num_top_AEs = 10,
                              num_top_drugs = 8,
@@ -194,6 +270,71 @@ eyeplot_pvEBayes <- function(x,
                              x_lim_scalar = 1.3,
                              text_size = 3,
                              log_scale = FALSE) {
+  if (!(is.numeric(num_top_AEs) &&
+    length(num_top_AEs) == 1 &&
+    num_top_AEs %% 1 == 0 &&
+    num_top_AEs > 0)) {
+    stop("'num_top_AEs' must be a single positive integer.")
+  }
+  num_top_AEs <- as.integer(num_top_AEs)
+  if (!(is.numeric(num_top_drugs) &&
+    length(num_top_drugs) == 1 &&
+    num_top_drugs %% 1 == 0 &&
+    num_top_drugs > 0)) {
+    stop("'num_top_drugs' must be a single positive integer.")
+  }
+  num_top_drugs <- as.integer(num_top_drugs)
+  if (!(is.numeric(N_threshold) &&
+    length(N_threshold) == 1 &&
+    N_threshold %% 1 == 0 &&
+    N_threshold > 0)) {
+    stop("'N_threshold' must be a single positive integer.")
+  }
+  N_threshold <- as.integer(N_threshold)
+  if (!(is.numeric(text_size) &&
+    length(text_size) == 1 &&
+    text_size > 0)) {
+    stop("'text_size' must be a single positive integer.")
+  }
+  text_size <- as.numeric(text_size)
+
+  if (!(is.numeric(text_shift) &&
+    length(text_shift) == 1)) {
+    stop("'text_shift' must be a single numeric variable.")
+  }
+  text_shift <- as.numeric(text_shift)
+  if (!(is.numeric(x_lim_scalar) &&
+    length(x_lim_scalar) == 1) &&
+    x_lim_scalar > 0) {
+    stop("'x_lim_scalar' must be a single positive variable.")
+  }
+  text_shift <- as.numeric(text_shift)
+  if (!(is.logical(log_scale) &&
+    length(log_scale) == 1)) {
+    stop("'log_scale' must be a single logical value (TRUE or FALSE).")
+  }
+
+  if (!is.null(specified_AEs) &
+    !(is.character(specified_AEs) &&
+      length(specified_AEs) >= 1)) {
+    stop("Elements in 'specified_AEs' must be entirely of strings.")
+  }
+  if (!is.null(specified_AEs)) {
+    specified_AEs <- as.character(specified_AEs)
+  }
+
+  if (!is.null(specified_drugs) &
+    !(is.character(specified_drugs) &&
+      length(specified_drugs) >= 1)) {
+    stop("Elements in 'specified_drugs' must be entirely of strings.")
+  }
+  if (!is.null(specified_drugs)) {
+    specified_drugs <- as.character(specified_drugs)
+  }
+
+
+
+
   top_drugs <- num_top_drugs
   top_AEs <- num_top_AEs
   AEs <- specified_AEs
@@ -203,7 +344,7 @@ eyeplot_pvEBayes <- function(x,
   }
   stopifnot(is.pvEBayes(x))
   if (is.null(x$posterior_draws)) {
-    x <- x %>% posterior_draws
+    x <- x %>% posterior_draws()
   }
 
   counts_long <- x$contin_table %>%
@@ -285,11 +426,17 @@ eyeplot_pvEBayes <- function(x,
     dat_plot$post_draws[dat_plot$post_draws == 0] <- 1e-10
     dat_plot$post_draws <- log(dat_plot$post_draws)
     q05_cutoff <- log(1.01)
-    xlab_text <- "Log signal strength (posterior median and 90% equi-tailed credible intervals)"
+    xlab_text <- paste0(
+      "Log signal strength (posterior median",
+      " and 90% equi-tailed credible intervals)"
+    )
     vline_x <- 0
   } else {
     q05_cutoff <- 1.01
-    xlab_text <- "Signal strength (posterior median and 90% equi-tailed credible intervals)"
+    xlab_text <- paste0(
+      "Signal strength (posterior median",
+      " and 90% equi-tailed credible intervals)"
+    )
     vline_x <- 1
   }
 
@@ -303,7 +450,9 @@ eyeplot_pvEBayes <- function(x,
       })
 
 
-  q05_table <- dat_plot[, list(q05 = stats::quantile(.SD$post_draws, 0.05)), by = group_vars]
+  q05_table <- dat_plot[, list(q05 = stats::quantile(.SD$post_draws, 0.05)),
+    by = group_vars
+  ]
 
   q05_table <- q05_table[q05_table$q05 > q05_cutoff, ]
   dat_plot <- dat_plot[q05_table, on = group_vars]
@@ -313,7 +462,7 @@ eyeplot_pvEBayes <- function(x,
     N = data.table::first(.SD$N),
     E = data.table::first(.SD$E),
     max_post_draws = max(.SD$post_draws),
-    q95 = stats::quantile(.SD$post_draws, probs = c(0.95))
+    q95 = stats::quantile(.SD$post_draws, probs = 0.95)
   ), by = group_vars, .SDcols = measure_vars]
 
   # Adding new columns using :=
@@ -338,7 +487,7 @@ eyeplot_pvEBayes <- function(x,
     ) +
     ggdist::stat_pointinterval(
       position = ggplot2::position_dodge(0.9),
-      .width = c(0.9),
+      .width = 0.9,
       point_interval = "median_qi"
     ) +
     ggplot2::scale_x_continuous(
@@ -384,6 +533,13 @@ eyeplot_pvEBayes <- function(x,
 }
 
 
+#' Capitalize the first character for each word
+#'
+#' @param x a vector of strings
+#'
+#' @returns a vector of strings
+#' @keywords internal
+#' @noRd
 .capitalize_words <- function(x) {
   vapply(x, function(s) {
     words <- strsplit(tolower(s), "\\s+")[[1]]
@@ -406,14 +562,15 @@ eyeplot_pvEBayes <- function(x,
 #'
 #' @param x a \code{pvEBayes} object, which is the output of the function
 #' \link{pvEBayes} or \link{pvEBayes_tune}.
-#' @param num_top_AEs number of most significant AEs appearing in the plot. Default to
-#' 10.
-#' @param num_top_drugs number of most significant drugs appearing in the plot. Default
-#' to 7.
-#' @param specified_AEs a vector of AE names that are specified to appear in the plot. If
-#' a vector of AEs is given, argument num_top_AEs will be ignored.
-#' @param specified_drugs a vector of drug names that are specified to appear in the plot.
-#' If a vector of drugs is given, argument num_top_drugs will be ignored.
+#' @param num_top_AEs number of most significant AEs appearing in the plot.
+#' Default to 10.
+#' @param num_top_drugs number of most significant drugs appearing in the plot.
+#' Default to 7.
+#' @param specified_AEs a vector of AE names that are specified to appear in the
+#' plot. If a vector of AEs is given, argument num_top_AEs will be ignored.
+#' @param specified_drugs a vector of drug names that are specified to appear in
+#' the plot. If a vector of drugs is given, argument num_top_drugs will be
+#' ignored.
 #' @param cutoff_signal numeric. Threshold for signal detection. An AE-drug
 #' combination is classified as a detected signal if its 5th posterior
 #' percentile exceeds this threshold.
@@ -434,15 +591,76 @@ eyeplot_pvEBayes <- function(x,
 #'
 #' heatmap_pvEBayes(
 #'   x = fit,
-#'   cutoff = 1.001
+#'   num_top_AEs = 10,
+#'   num_top_drugs = 8,
+#'   specified_AEs = NULL,
+#'   specified_drugs = NULL,
+#'   cutoff_signal = 1.001
 #' )
 #'
+#' @srrstats {G2.0, G2.1, G2.2} length and value of single and vector inputs are properly
+#' checked.
+#' @srrstats {G2.0a, G2.1a} The length of single and vector inputs are explicitly
+#' described in the corresponding documentation.
+#' @srrstats {G2.4, G2.4a, G2.4b, G2.4c, G2.8} explicit conversion is used for
+#' integer, continuous and character inputs.
+#' @srrstats {G2.9, G2.10} inconsistent return when extracting a matrix is
+#' addressed.
+#'
 heatmap_pvEBayes <- function(x,
                              num_top_AEs = 10,
                              num_top_drugs = 8,
                              specified_AEs = NULL,
                              specified_drugs = NULL,
                              cutoff_signal = NULL) {
+  if (!(is.numeric(num_top_AEs) &&
+    length(num_top_AEs) == 1 &&
+    num_top_AEs %% 1 == 0 &&
+    num_top_AEs > 0)) {
+    stop("'num_top_AEs' must be a single positive integer.")
+  }
+  num_top_AEs <- as.integer(num_top_AEs)
+  if (!(is.numeric(num_top_drugs) &&
+    length(num_top_drugs) == 1 &&
+    num_top_drugs %% 1 == 0 &&
+    num_top_drugs > 0)) {
+    stop("'num_top_drugs' must be a single positive integer.")
+  }
+  num_top_drugs <- as.integer(num_top_drugs)
+
+  if (!is.null(specified_AEs) &
+    !(is.character(specified_AEs) &&
+      length(specified_AEs) >= 1)) {
+    stop("Elements in 'specified_AEs' must be entirely of strings.")
+  }
+  if (!is.null(specified_AEs)) {
+    specified_AEs <- as.character(specified_AEs)
+  }
+
+  if (!is.null(specified_drugs) &
+    !(is.character(specified_drugs) &&
+      length(specified_drugs) >= 1)) {
+    stop("Elements in 'specified_drugs' must be entirely of strings.")
+  }
+  if (!is.null(specified_drugs)) {
+    specified_drugs <- as.character(specified_drugs)
+  }
+  if (!is.null(cutoff_signal) &
+    !(is.numeric(cutoff_signal) &&
+      length(cutoff_signal) == 1 &&
+      cutoff_signal > 0)) {
+    stop(
+      paste0(
+        "'cutoff_signal' must be a single positive ",
+        "variable that is greater than 1."
+      )
+    )
+  }
+  if (!is.null(cutoff_signal)) {
+    cutoff_signal <- as.numeric(cutoff_signal)
+  }
+
+
   top_drugs <- num_top_drugs
   top_AEs <- num_top_AEs
   AEs <- specified_AEs
@@ -459,7 +677,7 @@ heatmap_pvEBayes <- function(x,
 
   stopifnot(is.pvEBayes(x))
   if (is.null(x$posterior_draws)) {
-    x <- x %>% posterior_draws
+    x <- x %>% posterior_draws()
   }
   counts_long <- x$contin_table %>%
     as.data.frame() %>%
@@ -467,8 +685,6 @@ heatmap_pvEBayes <- function(x,
     data.table::as.data.table() %>%
     data.table::melt(id.vars = "AE", variable.name = "drug", value.name = "N")
   Es_long <- x$E
-
-
   Es_long <- Es_long %>%
     round(2) %>%
     as.data.frame() %>%
@@ -695,10 +911,11 @@ print.pvEBayes <- function(x, ...) {
 #' @param object a \code{pvEBayes} object, which is the output of the function
 #' \link{pvEBayes} or \link{pvEBayes_tune}.
 #'
-#' @param return A character string specifying which component the summary
+#' @param return a character string specifying which component the summary
 #'  function should return.Valid options include: "prior parameters",
 #' "likelihood", "detected signal" and "posterior draws". If set to NULL
-#' (default), all components will be returned in a list.
+#' (default), all components will be returned in a list. Note that the input
+#' for 'return' is case-sensitive.
 #'
 #' @param ... other input parameters. Currently unused.
 #'
@@ -717,7 +934,16 @@ print.pvEBayes <- function(x, ...) {
 #' )
 #'
 #' summary(obj)
-summary.pvEBayes <- function(object, return = NULL,...) {
+#'
+#' @srrstats {G2.0, G2.1, G2.2} length and value of single and vector inputs are
+#' properly checked.
+#' @srrstats {G2.0a, G2.1a} The length of single and vector inputs are
+#' explicitly described in the corresponding documentation.
+#' @srrstats {G2.3, G2.3a, G2.3b} character inputs are explicitly documented
+#' that they are strictly case-sensitive and only applicable to expected values.
+#'
+#'
+summary.pvEBayes <- function(object, return = NULL, ...) {
   stopifnot(is.pvEBayes(object))
   if (is.null(object$posterior_draws)) {
     object <- posterior_draws(object, n_posterior_draws = 1000)
@@ -741,19 +967,25 @@ summary.pvEBayes <- function(object, return = NULL,...) {
       h = object$h
     )
   }
-  if(!is.null(return)){
-    if(return == "prior parameters"){
+  if (!is.null(return)) {
+    if (return == "prior parameters") {
       estimated_prior
-    }else if(return == "likelihood"){
+    } else if (return == "likelihood") {
       object$loglik
-    }else if(return == "detected signal"){
+    } else if (return == "detected signal") {
       (.get_posterior_prob(object) >= 0.95)
-    }else if(return ==  "posterior draws"){
+    } else if (return == "posterior draws") {
       object$posterior_draws
-    }else{
-      stop("Please provide a valid return argument.")
+    } else {
+      stop(
+        paste0(
+          "'return' must be one of the followings: ",
+          "'prior parameters', 'likelihood', ",
+          "'detected signal' or 'posterior draws'."
+        )
+      )
     }
-  }else{
+  } else {
     res <- list(
       estimated_prior = estimated_prior,
       log_marginal_likelihood = object$loglik,
@@ -762,8 +994,6 @@ summary.pvEBayes <- function(object, return = NULL,...) {
     )
     res
   }
-
-
 }
 
 
@@ -779,9 +1009,10 @@ summary.pvEBayes <- function(object, return = NULL,...) {
 #' \link{pvEBayes} or \link{pvEBayes_tune}.
 #' @param type character string determining the type of plot to show.
 #' Available choices are `"eyeplot"` which calls \link{eyeplot_pvEBayes} and
-#' `"heatmap"` which calls \link{heatmap_pvEBayes}, with the additional arguments
-#' supplied in ...
-#' @param ... additional arguments passed to heatmap_pvEBayes or eyeplot_pvEBayes.
+#' `"heatmap"` which calls \link{heatmap_pvEBayes}. Note that the input for
+#' 'type' is case-sensitive.
+#' @param ... additional arguments passed to heatmap_pvEBayes or
+#' eyeplot_pvEBayes.
 #'
 #' @return
 #'
@@ -792,14 +1023,24 @@ summary.pvEBayes <- function(object, return = NULL,...) {
 #'
 #' obj <- pvEBayes(statin2025_44, model = "general-gamma", alpha = 0.5)
 #' plot(obj, type = "eyeplot")
+#'
+#' @srrstats {G2.0, G2.1, G2.2} length and value of single and vector inputs are properly
+#' checked.
+#' @srrstats {G2.0a, G2.1a} The length of single and vector inputs are explicitly
+#' described in the corresponding documentation.
+#' @srrstats {G2.3, G2.3a, G2.3b} character inputs are explicitly documented
+#' that they are strictly case-sensitive and only applicable to expected values.
+#'
 plot.pvEBayes <- function(x, type = "eyeplot", ...) {
   if (!is.pvEBayes(x)) {
     stop("x must be a 'pvEBayes' object.")
   }
 
-  stopifnot(
-    type %in% c("heatmap", "eyeplot")
-  )
+  if (
+    !(type %in% c("heatmap", "eyeplot"))
+  ) {
+    stop("'type' must be either 'heatmap' or 'eyeplot'")
+  }
 
   out <- if (type == "heatmap") {
     heatmap_pvEBayes(x, ...)
@@ -841,7 +1082,7 @@ logLik.pvEBayes <- function(object, ...) {
   stopifnot(is.pvEBayes(object))
 
   res <- object$loglik
-  return(res)
+  res
 }
 
 
@@ -874,8 +1115,18 @@ logLik.pvEBayes <- function(object, ...) {
 #'
 #' AIC_score <- AIC(fit)
 #'
+#' @srrstats {G2.0, G2.1, G2.2} length and value of single and vector inputs are properly
+#' checked.
+#' @srrstats {G2.0a, G2.1a} The length of single and vector inputs are explicitly
+#' described in the corresponding documentation.
+#' @srrstats {G2.4, G2.4a, G2.8} explicit conversion is used for integer input.
+#'
 AIC.pvEBayes <- function(object, ..., k = 2) {
   stopifnot(is.pvEBayes(object))
+  if (!(is.numeric(k) && length(k) == 1)) {
+    stop("'k' must be a single integer.")
+  }
+  k <- as.integer(k)
   model <- object$model
   if (model == "KM") {
     penalty <- length(object$g)
@@ -887,7 +1138,7 @@ AIC.pvEBayes <- function(object, ..., k = 2) {
 
 
   AIC_score <- penalty * 2 - object$loglik * k
-  return(AIC_score)
+  AIC_score
 }
 
 
@@ -936,5 +1187,5 @@ BIC.pvEBayes <- function(object, ...) {
 
 
   BIC_score <- penalty * log(n) - object$loglik * 2
-  return(BIC_score)
+  BIC_score
 }
